@@ -1,11 +1,11 @@
 # TODO: _add_implicit_values unit test ensures NO changes for a fully specified file.
 from copy import deepcopy
+from type_infer.base import TypeInformation
 from lightwood.helpers.templating import call, inline_dict, align
 from lightwood.helpers.templating import _consolidate_analysis_blocks
 from lightwood.api import dtype
 from lightwood.api.types import (
     JsonAI,
-    TypeInformation,
     StatisticalAnalysis,
     ProblemDefinition,
 )
@@ -183,7 +183,7 @@ def generate_json_ai(
     """
     Given ``TypeInformation``, ``StatisticalAnalysis``, and the ``ProblemDefinition``, generate a JSON config file with the necessary elements of the ML pipeline populated.
 
-    :param TypeInformation: Specifies what data types each column within the dataset are
+    :param TypeInformation: Specifies what data types each column within the dataset are. Generated by `mindsdb/type_infer`.
     :param statistical_analysis:
     :param problem_definition: Specifies details of the model training/building procedure, as defined by ``ProblemDefinition``
 
