@@ -1,4 +1,3 @@
-from lightwood.data.infer_types import infer_types
 from lightwood.data.statistical_analysis import statistical_analysis
 from lightwood.data.cleaner import cleaner
 from lightwood.data.splitter import splitter
@@ -6,5 +5,5 @@ from lightwood.data.timeseries_transform import transform_timeseries
 from lightwood.data.timeseries_analyzer import timeseries_analyzer
 from lightwood.data.encoded_ds import EncodedDs, ConcatedEncodedDs
 
-__all__ = ['infer_types', 'statistical_analysis', 'cleaner', 'splitter', 'transform_timeseries', 'timeseries_analyzer',
+__all__ = ['statistical_analysis', 'cleaner', 'splitter', 'transform_timeseries', 'timeseries_analyzer',
            'EncodedDs', 'ConcatedEncodedDs']
